--
-- InteractiveWindows v4.0.1
--
-- Interface: 1.4.4.0 1.4.4RC8
--
-- Specialization for an interactive control
--
-- @author      Manuel Leithner (SFM-Modding)
-- @version     v3.0
-- @date        24/10/12
-- @history:    v1.0 - Initial version
--              v2.0 - converted to ls2011
--              v3.0 - converted to ls2013
-- 20/02/2017	v4.0 - converted to LS2017
-- 16/08/2017	v4.0.1 - changes as see below.
--
-- v4.0 Converted and adapted to LS/FS 2017 including MP Support.  -  GtX | Andy
-- v4.0.1 Fixed issue with animations not displaying for all MP players.  -  GtX | Andy
--
-- Support for v4.0 and above.  @  http://ls-modcompany.com
--
--
-- free for noncommerical-usage
--
--
----------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	Support and questions for this version of the Script available: http://ls-modcompany.com	GtX | Andy	--
----------------------------------------------------------------------------------------------------------------------------------------------------------------------
--
--
--
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	HOW TO USE - "vehicle.xml" - Information:
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	
--	name			=	This is the displayed name of the function (Must be entered in the modDesc as in example below).
--	mark			=	This is the icon/mark that is displayed when IC is active and shows the user where to click.
--	size			=	This is the click radius of the mark. (Recommended 0.01 - 0.03)
--	animName		=	This is the animation that will be peformed when mark is clicked in game. (Is not active when animation is at start.)
--	playClickSound	=	If "true" then this will enable a click sound when an action is peformed on a "mark".
--	onMessage		=	This is the message displayed when function is not active. (This is written in string format so " %s " must be added at the place you would like the "name" displayed) See Example.
--	offMessage		=	This is the message displayed when function is active. 	   (This is written in string format so " %s " must be added at the place you would like the "name" displayed) See Example.
--
--	NOTE!!!!		=	If no "onMessage" or "offMessage" is set then the defualt "Turn ON %s" and "Turn OFF %s" will be used. (This is drawn from Base Game so all languages are supported).
--
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-- EXAMPLE FOR XML:
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--
--	<windows>
--		<window name="leftWindow"  mark="0>12|0|8|6" size="0.03" animName="leftWindow"  onMessage="ic_component_open" offMessage="ic_component_close" />
--		<window name="rightWindow" mark="0>12|0|8|7" size="0.03" animName="rightWindow" onMessage="ic_component_open" offMessage="ic_component_close" />
--		<window name="icScreen"	   mark="0>12|0|8|0" size="0.01" animName="screenDisplay" playClickSound="true"/>
--	</windows>
--
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	EXAMPLE FOR MODDESC:
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--
--	<l10n>
--
--		<text name="leftWindow">
--			<en>Left Window</en>
--			<de>Fenster links</de>
--           <fr>Fenêtre gauche</fr>
--			<es>Ventanilla izquierda</es>
--			<it>Finestra sinistra</it>
--		</text>
--		
--		<text name="rightWindow">
--			<en>Right Window</en>
--			<de>Fenster rechts</de>
--          <fr>Fenêtre droite</fr>
--			<es>Ventanilla derecha</es>	
--			<it>Finestra destra</it>
--		</text>
--
--		<text name="ic_component_close">
--			<en>Close %s</en>
--			<de>%s schließen</de>		
--			<fr>%s ferme </fr>
--			<es>Cerrar %s</es>
--			<it>Chiudi %s</it>
--		</text>
--		
--		<text name="ic_component_open">
--			<en>Open %s</en>
--			<de>%s öffnen</de>		
--			<fr>ouvrir %s</fr>
--			<fr>%s ouvrir </fr>
--			<es>Abrir %s</es>
--			<it>Apri %s</it>
--		</text>
--		
--	</l10n>		
--
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	END:
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--



InteractiveWindows = {};

function InteractiveWindows.prerequisitesPresent(specializations)
	if not SpecializationUtil.hasSpecialization(InteractiveControl, specializations) then print("Warning: Specialization InteractiveWindows v4.0.1 needs the specialization InteractiveControl v4.1"); end;
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations) and SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function InteractiveWindows:load(savegame)

    local i=0;
    while true do
        local windowName = string.format("vehicle.interactiveComponents.windows.window(%d)", i);
        if not hasXMLProperty(self.xmlFile, windowName) then
            break;
        end;
        local animation = getXMLString(self.xmlFile, windowName .. "#animName");
        local name = Utils.getNoNil(g_i18n:getText(getXMLString(self.xmlFile, windowName .. "#name")), "ERROR");
        local mark = Utils.indexToObject(self.components, getXMLString(self.xmlFile, windowName .. "#mark"));
        local highlight = getChildAt(mark, 0);
        local size = Utils.getNoNil(getXMLFloat(self.xmlFile, windowName .. "#size"), 0.1);
        local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, windowName .. "#onMessage"), "action_turnOnOBJECT"));
        local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, windowName .. "#offMessage") , "action_turnOffOBJECT"));
		
		local playWcSound = Utils.getNoNil(getXMLBool(self.xmlFile, windowName .. "#playClickSound"), false);
		
        local window = Window:new(highlight, name, animation, mark, size, self, onMessage, offMessage, playWcSound);
        window.synch = Utils.getNoNil(getXMLBool(self.xmlFile, windowName .. "#synch"), true);
        table.insert(self.interactiveObjects, window);
        i = i + 1;
    end;
end;

function InteractiveWindows:delete()
end;

function InteractiveWindows:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveWindows:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveWindows:update(dt)
end;

function InteractiveWindows:draw()
end;



--
-- Window Class
-- Specifies an interactive window
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  26/12/09
--

Window = {};

function Window:new(highlight, name, animation, mark, size, vehicle, onMessage, offMessage, playWcSound)

    local Window_mt = Class(Window, InteractiveComponentInterface);
    local instance = InteractiveComponentInterface:new(nil, highlight, name, mark, size, onMessage, offMessage, Window_mt);
    instance.vehicle = vehicle;
    instance.animation = animation;
	instance.playWcSound = playWcSound;

    return instance;
end;

function Window:delete()
    InteractiveComponentInterface.delete(self);
end;

function Window:mouseEvent(posX, posY, isDown, isUp, button)
    InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Window:keyEvent(unicode, sym, modifier, isDown)
    InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Window:update(dt)
    InteractiveComponentInterface.update(self, dt);	
end;

function Window:draw()
    InteractiveComponentInterface.draw(self);
end;

function Window:doAction(noEventSend, forceAction)
    InteractiveComponentInterface.doAction(self, forceAction);
	
	local animTime = self.vehicle:getAnimationTime(self.animation)	
	
	if self.isOpen and animTime < 1 then
		self.vehicle:playAnimation(self.animation, 1, animTime, false)
	elseif not self.isOpen and animTime > 0 then
		self.vehicle:playAnimation(self.animation, -1, animTime, false)
	end;
	
	if self.vehicle ~= nil then
		if self.playWcSound ~= nil and self.vehicle:getIsActiveForSound() then
			if self.playWcSound then
				SoundUtil.playSample(g_currentMission.sampleToggleLights, 1, 0, 1);
			end;
		end;
	end;
end;

function Window:onEnter()
    InteractiveComponentInterface.onEnter(self);
end;

function Window:onExit()
    InteractiveComponentInterface.onExit(self);
end;

function Window:setActive()
    InteractiveComponentInterface.setActive(self, isActive);
end;

function Window:setVisible(isVisible)
    InteractiveComponentInterface.setVisible(self, isVisible);
end;